==> gnuradio_3.6.4.1.orig.tar.gz: gnuradio-3.6.4.1/gr-analog/include/analog/feedforward_agc_cc.h <==
/* -*- c++ -*- */
/*
 * Copyright 2006,2012 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_ANALOG_FEEDFORWARD_AGC_CC_H
#define INCLUDED_ANALOG_FEEDFORWARD_AGC_CC_H

#include <analog/api.h>
#include <gr_sync_block.h>

namespace gr {
  namespace analog {

    /*!
     * \brief Non-causal AGC which computes required gain based on max absolute value over nsamples
     * \ingroup level_blk
     */
    class ANALOG_API feedforward_agc_cc : virtual public gr_sync_block
    {
    public:
      // gr::analog::feedforward_agc_cc::sptr
      typedef boost::shared_ptr<feedforward_agc_cc> sptr;
      
      static sptr make(int nsamples, float reference);
    };
    
  } /* namespace analog */
} /* namespace gr */

#endif /* INCLUDED_GR_FEEDFORWARD_AGC_CC_H */

==> gnuradio_3.6.5.1.orig.tar.gz: gnuradio-3.6.5.1/gr-analog/include/analog/feedforward_agc_cc.h <==
/* -*- c++ -*- */
/*
 * Copyright 2006,2012 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_ANALOG_FEEDFORWARD_AGC_CC_H
#define INCLUDED_ANALOG_FEEDFORWARD_AGC_CC_H

#include <analog/api.h>
#include <gr_sync_block.h>

namespace gr {
  namespace analog {

    /*!
     * \brief Non-causal AGC which computes required gain based on max absolute value over nsamples
     * \ingroup level_controllers_blk
     */
    class ANALOG_API feedforward_agc_cc : virtual public gr_sync_block
    {
    public:
      // gr::analog::feedforward_agc_cc::sptr
      typedef boost::shared_ptr<feedforward_agc_cc> sptr;
      
      static sptr make(int nsamples, float reference);
    };
    
  } /* namespace analog */
} /* namespace gr */

#endif /* INCLUDED_GR_FEEDFORWARD_AGC_CC_H */
